@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 # Stalker a Production Asset Management System
-# Copyright (C) 2009-2013 Erkan Ozgur Yilmaz
+# Copyright (C) 2009-2014 Erkan Ozgur Yilmaz
 #
 # This file is part of Stalker.
 #
@@ -57,7 +57,7 @@ class Note(SimpleEntity):
 
     content = synonym(
         'description',
-        doc="""The content of this :class:`~stalker.models.note.Note` instance.
+        doc="""The content of this :class:`.Note` instance.
 
         Content is a string representing the content of this Note, can be an
         empty.
