@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 # Stalker a Production Asset Management System
-# Copyright (C) 2009-2013 Erkan Ozgur Yilmaz
+# Copyright (C) 2009-2014 Erkan Ozgur Yilmaz
 #
 # This file is part of Stalker.
 #
@@ -40,13 +40,11 @@ class Type(Entity, TargetEntityTypeMixin, CodeMixin):
     Type is a generalized version of the previous design that defines types for
     specific classes.
 
-    The purpose of the :class:`~stalker.models.type.Type` class is just to
-    define a new type for a specific :class:`~stalker.models.entity.Entity`.
-    For example, you can have a ``Character``
-    :class:`~stalker.models.asset.Asset` or you can have a ``Commercial``
-    :class:`~stalker.models.project.Project` or you can define a
-    :class:`~stalker.models.link.Link` as an ``Image`` etc.,
-    to create a new :class:`~stalker.models.type.Type` for various classes::
+    The purpose of the :class:`.Type` class is just to define a new type for a
+    specific :class:`.Entity`. For example, you can have a ``Character``
+    :class:`.Asset` or you can have a ``Commercial`` :class:`.Project` or you
+    can define a :class:`.Link` as an ``Image`` etc., to create a new
+    :class:`.Type` for various classes::
 
       Type(name="Character", target_entity_type="Asset")
       Type(name="Commercial", target_entity_type="Project")
@@ -64,14 +62,13 @@ class Type(Entity, TargetEntityTypeMixin, CodeMixin):
       Type(name="Commercial", target_entity_type=Project)
       Type(name="Image", target_entity_type=Link)
 
-    By using :class:`~stalker.models.type.Type`\ s, one can able to sort and
-    group same type of entities.
+    By using :class:`.Type`\ s, one can able to sort and group same type of
+    entities.
 
-    :class:`~stalker.models.type.Type`\ s are generally used in
-    :class:`~stalker.models.type.Structure`\ s.
+    :class:`.Type`\ s are generally used in :class:`.Structure`\ s.
 
     :param string target_entity_type: The string defining the target type of
-      this :class:`~stalker.models.type.Type`.
+      this :class:`.Type`.
     """
     __auto_name__ = False
     __tablename__ = "Types"
@@ -100,7 +97,7 @@ class Type(Entity, TargetEntityTypeMixin, CodeMixin):
 
         return not self.__eq__(other)
 
-# TODO: add a comparator as you did in oyProjectManager VersionStatusComparator
+
 class EntityType(Base):
     """A simple class just to hold the registered class names in Stalker
     """
@@ -110,6 +107,7 @@ class EntityType(Base):
     id = Column("id", Integer, primary_key=True)
     name = Column(String(128), nullable=False, unique=True)
     statusable = Column(Boolean, default=False)
+    dateable = Column(Boolean, default=False)
     schedulable = Column(Boolean, default=False)
     accepts_references = Column(Boolean, default=False)
 
@@ -125,4 +123,3 @@ class EntityType(Base):
         self.accepts_references = accepts_references
 
         # TODO: add tests for the name attribute
-
